 Changelog
 =========

All noteable changes to this project, *colab-env*, will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [unreleased]

### Added
 - N/A

### Changed
 - N/A

### Removed
 - N/A

## [0.0.1] - 2019-07-05

Initial version. Handles environment variables in Google Colab via a Google Drive file called `vars.env`.
